const express = require('express');
const mysql = require('mysql');
const cors = require('cors');
const app = express();
const port = 5000;

// MySQL database connection configuration
const db = mysql.createConnection({
  host: 'localhost',
  user: 'root',
  password: '', // Enter your MySQL password here
  database: 'rptestdb',
});

// Connect to MySQL
db.connect((err) => {
  if (err) {
    console.error('Error connecting to MySQL:', err);
    return;
  }
  console.log('Connected to MySQL');
});

// Enable CORS
app.use(cors());

// Sample route to get data from MySQL
app.get('/api/tasks', (req, res) => {
  const query = 'SELECT * FROM assignedtask';

  db.query(query, (err, results) => {
    if (err) {
      console.error('Error executing MySQL query:', err);
      res.status(500).json({ error: 'Error fetching data from MySQL' });
      return;
    }

    res.json(results);
  });
});

// Route to fetch user data by user_id
app.get('/api/users/:userId', (req, res) => {
  const userId = req.params.userId;
  const query = 'SELECT user_name FROM user WHERE user_id = ?';

  db.query(query, [userId], (err, results) => {
    if (err) {
      console.error('Error executing MySQL query:', err);
      res.status(500).json({ error: 'Error fetching user data from MySQL' });
      return;
    }

    if (results.length > 0) {
      res.json(results[0].user_name);
    } else {
      res.status(404).json({ error: 'User not found' });
    }
  });
});

// Route to fetch task data by task_id
app.get('/api/tasks/:taskId', (req, res) => {
  const taskId = req.params.taskId;
  const query = 'SELECT description FROM task WHERE task_id = ?';


  db.query(query, [taskId], (err, results) => {
    if (err) {
      console.error('Error executing MySQL query:', err);
      res.status(500).json({ error: 'Error fetching task data from MySQL' });
      return;
    }

    if (results.length > 0) {
      res.json(results[0].description);
    } else {
      res.status(404).json({ error: 'Task not found' });
    }
  });
});

app.listen(port, () => {
  console.log(`Server is running on port ${port}`);
});
